'use strict';

exports.__esModule = true;
exports.default = createContainerQueryMixin;

var _raf = require('./raf');

var _containerQuery = require('./containerQuery');

function createContainerQueryMixin(query) {

  var getClasses = (0, _containerQuery.parseQuery)(query);

  return {
    defineContainer: function defineContainer(component) {
      this._containerElement = component;
    },
    componentDidMount: function componentDidMount() {
      var _this = this;

      this._containerQuerySelectorMap = {};
      this._size = { width: null, height: null };
      this._rafId = null;

      var checkDimension = function checkDimension() {
        var _containerElement = _this._containerElement;
        var width = _containerElement.clientWidth;
        var height = _containerElement.clientHeight;

        var changed = false;

        if (_this._size.width !== width) {
          changed = true;
        }

        if (_this._size.height !== height) {
          changed = true;
        }

        _this._size.width = width;
        _this._size.height = height;

        if (changed) {
          _this._updateAttributes();
        }

        _this._rafId = (0, _raf.requestAnimationFrame)(checkDimension);
      };

      checkDimension();
    },
    componentWillUnmount: function componentWillUnmount() {
      (0, _raf.cancelAnimationFrame)(this._rafId);
      this._rafId = null;
      this._containerElement = null;
    },
    _updateAttributes: function _updateAttributes() {
      var selectorMap = getClasses(this._size);

      if ((0, _containerQuery.isSelectorMapEqual)(this._containerQuerySelectorMap, selectorMap)) {
        return;
      }

      this._containerQuerySelectorMap = selectorMap;

      for (var _iterator = (0, _containerQuery.toPairs)(this._containerQuerySelectorMap), _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
        var _ref;

        if (_isArray) {
          if (_i >= _iterator.length) break;
          _ref = _iterator[_i++];
        } else {
          _i = _iterator.next();
          if (_i.done) break;
          _ref = _i.value;
        }

        var _ref2 = _ref;
        var selectorName = _ref2[0];
        var isOn = _ref2[1];

        if (isOn) {
          this._containerElement.setAttribute(selectorName, '');
        } else {
          this._containerElement.removeAttribute(selectorName);
        }
      }
    }
  };
}